/* Copyright 2010 ESRI
* 
* All rights reserved under the copyright laws of the United States
* and applicable international laws, treaties, and conventions.
* 
* You may freely redistribute and use this sample code, with or
* without modification, provided you include the original copyright
* notice and use restrictions.
* 
* See the use restrictions at http://help.arcgis.com/en/sdk/10.0/usageRestrictions.htm
* 
*/
package com.esri.arcgis.sample.simplerouting;

import com.esri.arcgis.sample.simplerouting.SimpleRoutingTask;
import com.esri.adf.web.data.tasks.SimpleTaskInfo;
import com.esri.adf.web.data.tasks.TaskActionDescriptor;
import com.esri.adf.web.data.tasks.TaskActionDescriptorModel;
import com.esri.adf.web.data.tasks.TaskDescriptor;
import com.esri.adf.web.data.tasks.TaskParamDescriptor;
import com.esri.adf.web.data.tasks.TaskParamDescriptorModel;

public final class SimpleRoutingTaskInfo extends SimpleTaskInfo {
  private TaskDescriptor taskDesc = null;
  private TaskActionDescriptor[] taskActionDescriptors = null;
  private TaskParamDescriptorModel[] taskParamDescriptors = null;
  private TaskParamDescriptor errorMessage = null;

  /**
   * default constructor
   *
   */
  public SimpleRoutingTaskInfo() {
    taskDesc = new TaskDescriptor(SimpleRoutingTask.class, "Simple Routing Task",
        "Simple Routing Task");
    taskActionDescriptors = new TaskActionDescriptor[2];

    taskActionDescriptors[0] = new TaskActionDescriptor(SimpleRoutingTask.class, "computeRoute",
        "Compute Route");
    taskActionDescriptors[0].setToolTip("Compute Route");
    taskActionDescriptors[0].setDefaultImage("images/tasks/routing/solve.gif");
    taskActionDescriptors[0].setSelectedImage("images/tasks/routing/solveD.gif");
    taskActionDescriptors[0].setHoverImage("images/tasks/routing/solveU.gif");
    taskActionDescriptors[0].setDisabledImage("images/tasks/routing/solveX.gif");
    taskActionDescriptors[0].setRendererType(TaskActionDescriptor.IMAGE_RENDERER_TYPE);

    taskActionDescriptors[1] = new TaskActionDescriptor(SimpleRoutingTask.class, "clearRoute",
        "Clear Route");
    taskActionDescriptors[1].setToolTip("Clear Route");
    taskActionDescriptors[1].setDefaultImage("images/tasks/routing/clearroute.gif");
    taskActionDescriptors[1].setSelectedImage("images/tasks/routing/clearrouteD.gif");
    taskActionDescriptors[1].setHoverImage("images/tasks/routing/clearrouteU.gif");
    taskActionDescriptors[1].setDisabledImage("images/tasks/routing/clearrouteX.gif");
    taskActionDescriptors[1].setRendererType(TaskActionDescriptor.IMAGE_RENDERER_TYPE);

    // Class taskClass, String paramName, String displayName, String
    // readMethodName, String writeMethodName
    errorMessage = new TaskParamDescriptor(SimpleRoutingTask.class, "errorMessage", "");
  }

  /**
   * returns a task descriptor
   */
  public TaskDescriptor getTaskDescriptor() {
    return taskDesc;
  }

  /**
   * returns action descriptors
   */
  public TaskActionDescriptorModel[] getActionDescriptors() {
    return taskActionDescriptors;
  }

  /**
   * returns parameter descriptors
   */
  public TaskParamDescriptorModel[] getParamDescriptors() {
    return taskParamDescriptors;
  }

  /**
   * sets parameter descriptors. This method is called during the initialization
   * of SimpleRoutingTask.
   *
   * @param flds
   *          corresponds to the imput fields of the currently instantiated
   *          geocoder.
   */
  public void setParamDescriptors(String[] flds) {
    taskParamDescriptors = new TaskParamDescriptorModel[(flds.length * 2) + 1];
    for (int i = 0; i < flds.length; i++)
      taskParamDescriptors[i] = new RoutingTaskParamDescriptor(flds[i], flds[i]);
    for (int i = 0; i < flds.length; i++)
      taskParamDescriptors[i + flds.length] = new RoutingTaskParamDescriptor(flds[i], flds[i] + 2);

    taskParamDescriptors[flds.length * 2] = errorMessage;
  }

}
